# CDAPTools : Climate data Downloading And Processing Tools


[![image](https://img.shields.io/pypi/v/cdaptools.svg)](https://pypi.python.org/pypi/cdaptools)
[![image](https://img.shields.io/conda/vn/conda-forge/cdaptools.svg)](https://anaconda.org/conda-forge/CDAPTools))
[![image](https://github.com/javedali99/CDAPTools/workflows/docs/badge.svg)](https://javedali99.github.io/CDAPTools/)
[![image](https://github.com/javedali99/CDAPTools/workflows/build/badge.svg)](https://github.com/javedali99/CDAPTools/actions?query=workflow%3Abuild)
[![image](https://img.shields.io/twitter/follow/javedali99?style=social)](https://twitter.com/javedali99)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

**Tools for downloading and processing climatic data for analyzing multi-hazards risk and compound weather and climate extreme events.**

`CDAPTools` is a collection of functions that allows you to download atmospheric data from different sources, extract data from a NetCDF file for a particular region, process the data for further analysis, visualizing the data and apply two different methodologies we developed for analyzing multi-hazard risks and estimating compound effects of different weather and climate extreme events.

-   Free software: MIT license
-   Documentation: https://javedali99.github.io/CDAPTools/
    

## Features

-   TODO

## TO DO

Add following:

- Functions developed for data downloading and processing
- Functions for estimating quantiles of climate drivers
- Functions for method-1 and method-2
- Functions for mapping and visualizing the data

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.


